<?php

namespace SGalinski\SgNews\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (http://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SGalinski\SgNews\Domain\Model\Category;
use SGalinski\SgNews\Domain\Model\News;
use TYPO3\CMS\Core\Utility\GeneralUtility;

/**
 * Controller that shows the latest news
 */
class LatestController extends AbstractController {
	/**
	 * @inject
	 * @var \SGalinski\SgNews\Domain\Repository\CategoryRepository
	 */
	protected $categoryRepository;

	/**
	 * @inject
	 * @var \SGalinski\SgNews\Domain\Repository\NewsRepository
	 */
	protected $newsRepository;

	/**
	 * Renders the news overview
	 *
	 * @return void
	 */
	public function indexAction() {
		$limit = ((int) $this->settings['limit']);
		$limit = ($limit < 1 ? 1 : $limit);

		$filterByCategories = FALSE;
		$categoryUids = GeneralUtility::intExplode(',', $this->settings['categories']);
		foreach ($categoryUids as $categoryUid) {
			if ($categoryUid > 0) {
				$filterByCategories = TRUE;
				break;
			}
		}

		$latestNewsEntries = $this->newsRepository->findLastUpdatedOrHighlightedNewsByCategories(
			$limit, FALSE, ($filterByCategories ? $categoryUids : NULL)
		);

		$newsMetaData = [];
		$categories = [];
		foreach ($latestNewsEntries as $latestNewsEntry) {
			/** @var News $latestNewsEntry */
			/** @var Category $category */

			$categoryUid = $latestNewsEntry->getPid();
			$category = $categories[$categoryUid];
			if (!$category) {
				$category = $this->categoryRepository->findByUid($categoryUid);
				if (!$category) {
					continue;
				}
				$categories[$categoryUid] = $category;
			}

			$newsMetaData[] = $this->getMetaDataForNews($latestNewsEntry, $category);
		}

		$this->view->assign('newsMetaData', $newsMetaData);
	}
}

?>
